@@ -364,7 +364,7 @@ const popupDataFromTabId = function(tabId, tabTitle) {
         tooltipsDisabled: µbus.tooltipsDisabled
     };
 
-    if ( µbhs.uiPopupConfig !== 'undocumented' ) {
+    if ( µbhs.uiPopupConfig !== 'unset' ) {
         r.uiPopupConfig = µbhs.uiPopupConfig;
     }
 
@@ -490,7 +490,8 @@ const onMessage = function(request, sender, callback) {
         const pageStore = µb.pageStoreFromTabId(request.tabId);
         if ( pageStore === null ) { break; }
         const supportURL = new URL(vAPI.getURL('support.html'));
-        supportURL.searchParams.set('reportURL', pageStore.rawURL);
+        supportURL.searchParams.set('pageURL', request.pageURL);
+        supportURL.searchParams.set('popupPanel', request.popupPanel);
         µb.openNewTab({ url: supportURL.href, select: true, index: -1 });
         break;
     }
